[llvm-commits] CVS: llvm/lib/Target/PowerPC/PPCTargetMachine.cpp

Evan Cheng evan.cheng at apple.com
Thu Feb 23 14:18:19 PST 2006



Changes in directory llvm/lib/Target/PowerPC:

PPCTargetMachine.cpp updated: 1.80 -> 1.81
---
Log message:

PPC JIT relocation model should be DynamicNoPIC.


---
Diffs of the changes:  (+2 -2)

 PPCTargetMachine.cpp |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


Index: llvm/lib/Target/PowerPC/PPCTargetMachine.cpp
diff -u llvm/lib/Target/PowerPC/PPCTargetMachine.cpp:1.80 llvm/lib/Target/PowerPC/PPCTargetMachine.cpp:1.81
--- llvm/lib/Target/PowerPC/PPCTargetMachine.cpp:1.80	Wed Feb 22 14:19:42 2006
+++ llvm/lib/Target/PowerPC/PPCTargetMachine.cpp	Thu Feb 23 16:18:07 2006
@@ -134,8 +134,8 @@
 }
 
 void PPCJITInfo::addPassesToJITCompile(FunctionPassManager &PM) {
-  // The JIT should use static relocation model.
-  TM.setRelocationModel(Reloc::Static);
+  // The JIT should use dynamic-no-pic relocation model.
+  TM.setRelocationModel(Reloc::DynamicNoPIC);
 
   // Run loop strength reduction before anything else.
   PM.add(createLoopStrengthReducePass());






More information about the llvm-commits mailing list